@@ -24,8 +24,7 @@ fn main() -> std::io::Result<()> {
     write!(
         file,
         r#"
-use crate::typeloader::{{VirtualFile, VirtualDirectory}};
-pub fn widget_library() -> &'static [(&'static str, &'static VirtualDirectory<'static>)] {{
+fn widget_library() -> &'static [(&'static str, &'static BuiltinDirectory<'static>)] {{
     &[
 "#
     )?;
@@ -55,7 +54,13 @@ fn process_style(path: &Path) -> std::io::Result<String> {
         .filter_map(Result::ok)
         .filter(|entry| {
             entry.path().is_file()
-                && entry.path().extension().unwrap_or_default() == std::ffi::OsStr::new("60")
+                && entry
+                    .path()
+                    .extension()
+                    .map(|ext| {
+                        ext == std::ffi::OsStr::new("60") || ext == std::ffi::OsStr::new("svg")
+                    })
+                    .unwrap_or_default()
         })
         .map(|entry| entry.path())
         .collect();
@@ -64,7 +69,7 @@ fn process_style(path: &Path) -> std::io::Result<String> {
         .iter()
         .map(|file| {
             format!(
-                "&VirtualFile {{path: r#\"{}\"# , contents: include_str!(r#\"{}\"#)}}",
+                "&BuiltinFile {{path: r#\"{}\"# , contents: include_bytes!(r#\"{}\"#)}}",
                 file.file_name().unwrap().to_string_lossy(),
                 file.display()
             )
