@@ -656,7 +656,8 @@ fn generate_component(
         .iter()
         .map(|(path, id)| {
             let symbol = format_ident!("SFPS_EMBEDDED_RESOURCE_{}", id);
-            quote!(const #symbol: &'static [u8] = ::core::include_bytes!(#path);)
+            let data = embedded_file_tokens(path);
+            quote!(const #symbol: &'static [u8] = #data;)
         })
         .collect();
 
@@ -1468,7 +1469,7 @@ fn compile_expression(expr: &Expression, component: &Rc<Component>) -> TokenStre
             let op = proc_macro2::Punct::new(*op, proc_macro2::Spacing::Alone);
             quote!( #op #sub )
         }
-        Expression::ImageReference(resource_ref) => {
+        Expression::ImageReference { resource_ref, .. } => {
             match resource_ref {
                 crate::expression_tree::ImageReference::None => {
                     quote!(sixtyfps::re_exports::Image::default())
@@ -1598,12 +1599,26 @@ fn compile_expression(expr: &Expression, component: &Rc<Component>) -> TokenStre
             let (padding, spacing) = generate_layout_padding_and_spacing(&layout.geometry, *o, component);
             let cells = grid_layout_cell_data(layout, *o, component);
             let size = layout_geometry_size(&layout.geometry.rect, *o, component);
-            quote!(solve_grid_layout(&GridLayoutData{
-                size: #size,
-                spacing: #spacing,
-                padding: #padding,
-                cells: Slice::from_slice(&#cells),
-            }))
+            if let (Some(button_roles), Orientation::Horizontal) = (&layout.dialog_button_roles, *o) {
+                let role = button_roles.iter().map(|x| format_ident!("{}", x));
+                quote!({
+                    let mut cells = #cells;
+                    reorder_dialog_button_layout(&mut cells, &[ #(DialogButtonRole::#role),* ]);
+                    solve_grid_layout(&GridLayoutData{
+                        size: #size,
+                        spacing: #spacing,
+                        padding: #padding,
+                        cells: Slice::from_slice(&cells),
+                    })
+                })
+            } else {
+                quote!(solve_grid_layout(&GridLayoutData{
+                    size: #size,
+                    spacing: #spacing,
+                    padding: #padding,
+                    cells: Slice::from_slice(&#cells),
+                }))
+            }
         }
         Expression::SolveLayout(Layout::BoxLayout(layout), o) => {
             let (padding, spacing) = generate_layout_padding_and_spacing(&layout.geometry, *o, component);
@@ -1626,8 +1641,8 @@ fn compile_expression(expr: &Expression, component: &Rc<Component>) -> TokenStre
             })
         }
         Expression::SolveLayout(Layout::PathLayout(layout), _) => {
-            let width = layout_geometry_size(&layout.rect,  Orientation::Horizontal, component);
-            let height = layout_geometry_size(&layout.rect,  Orientation::Vertical, component);
+            let width = layout_geometry_size(&layout.rect, Orientation::Horizontal, component);
+            let height = layout_geometry_size(&layout.rect, Orientation::Vertical, component);
             let elements = compile_path(&layout.path, component);
             let get_prop = |nr: &Option<NamedReference>| {
                 nr.as_ref().map_or_else(
@@ -2069,3 +2084,14 @@ fn compile_path(path: &Path, component: &Rc<Component>) -> TokenStream {
 fn access_component_field_offset(component_id: &Ident, field: &Ident) -> TokenStream {
     quote!({ *&#component_id::FIELD_OFFSETS.#field })
 }
+
+fn embedded_file_tokens(path: &str) -> TokenStream {
+    let file = crate::fileaccess::load_file(std::path::Path::new(path)).unwrap(); // embedding pass ensured that the file exists
+    match file.builtin_contents {
+        Some(static_data) => {
+            let literal = proc_macro2::Literal::byte_string(static_data);
+            quote!(#literal)
+        }
+        None => quote!(::core::include_bytes!(#path)),
+    }
+}
