@@ -20,7 +20,7 @@ This module has different sub modules with the actual parser functions
 
 use crate::diagnostics::{BuildDiagnostics, SourceFile, Spanned};
 pub use smol_str::SmolStr;
-use std::convert::TryFrom;
+use std::{convert::TryFrom, fmt::Display};
 
 mod document;
 mod element;
@@ -210,6 +210,21 @@ macro_rules! declare_syntax {
             )*
         }
 
+        impl Display for SyntaxKind {
+            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+                match self {
+                    $(Self::$token => {
+                        if let Some(character) = <dyn std::any::Any>::downcast_ref::<&str>(& $rule) {
+                            return write!(f, "'{}'", character)
+                        }
+                    })*
+                    _ => ()
+                }
+                write!(f, "{:?}", self)
+            }
+        }
+
+
         /// Returns a pair of the matched token type at the beginning of `text`, and its size
         pub fn lex_next_token(text : &str, state: &mut crate::lexer::LexState) -> Option<(usize, SyntaxKind)> {
             use crate::lexer::LexingRule;
@@ -496,7 +511,7 @@ mod parser_trait {
         /// Returns true if the token was consumed.
         fn expect(&mut self, kind: SyntaxKind) -> bool {
             if !self.test(kind) {
-                self.error(format!("Syntax error: expected {:?}", kind));
+                self.error(format!("Syntax error: expected {}", kind));
                 return false;
             }
             true
