@@ -78,9 +78,7 @@ pub async fn run_passes(
         lower_tabwidget::lower_tabwidget(component, &mut type_loader, diag).await;
     }
 
-    if compiler_config.embed_resources {
-        embed_resources::embed_resources(root_component);
-    }
+    embed_resources::embed_resources(root_component, compiler_config.embed_resources, diag);
 
     inlining::inline(doc);
     focus_item::resolve_element_reference_in_set_focus_calls(root_component, diag);
@@ -90,7 +88,7 @@ pub async fn run_passes(
     lower_states::lower_states(root_component, &doc.local_registry, diag);
     repeater_component::process_repeater_components(root_component);
     lower_popups::lower_popups(root_component, &doc.local_registry, diag);
-    lower_layout::lower_layouts(root_component, &global_type_registry.borrow(), diag);
+    lower_layout::lower_layouts(root_component, &mut type_loader, diag).await;
     z_order::reorder_by_z_order(root_component, diag);
     lower_shadows::lower_shadow_properties(root_component, &doc.local_registry, diag);
     clip::handle_clip(root_component, &global_type_registry.borrow(), diag);
@@ -102,13 +100,13 @@ pub async fn run_passes(
     default_geometry::default_geometry(root_component, diag);
     visible::handle_visible(root_component, &global_type_registry.borrow());
     materialize_fake_properties::materialize_fake_properties(root_component);
+    ensure_window::ensure_window(root_component, &doc.local_registry);
     apply_default_properties_from_style::apply_default_properties_from_style(
         root_component,
         &mut type_loader,
         diag,
     )
     .await;
-    ensure_window::ensure_window(root_component, &doc.local_registry);
     collect_globals::collect_globals(doc, diag);
     unique_id::assign_unique_id(root_component);
     binding_analysis::binding_analysis(root_component, diag);
