@@ -10,7 +10,6 @@ LICENSE END */
 //! Make sure that the top level element of the component is always a Window
 
 use crate::expression_tree::BindingExpression;
-use crate::langtype::Type;
 use crate::namedreference::NamedReference;
 use crate::object_tree::{Component, Element};
 use crate::typeregister::TypeRegister;
@@ -19,13 +18,12 @@ use std::collections::HashSet;
 use std::rc::Rc;
 
 pub fn ensure_window(component: &Rc<Component>, type_register: &TypeRegister) {
-    if component.root_element.borrow().base_type.to_string() == "Window" {
+    if matches!(component.root_element.borrow().base_type.to_string().as_str(), "Window" | "Dialog")
+    {
         return; // already a window, nothing to do
     }
 
-    let window_type = Type::Native(
-        type_register.lookup_element("Window").unwrap().as_builtin().native_class.clone(),
-    );
+    let window_type = type_register.lookup_element("Window").unwrap();
 
     let win_elem = component.root_element.clone();
 
