@@ -1,7 +1,7 @@
 /* LICENSE BEGIN
     This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2020 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2020 Simon Hausmann <simon.hausmann@sixtyfps.io>
+    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
+    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
 
     SPDX-License-Identifier: GPL-3.0-only
     This file is also available under commercial licensing terms.
@@ -24,14 +24,14 @@ enum FocusCheckResult {
 }
 
 fn element_focus_check(element: &ElementRc) -> FocusCheckResult {
-    if let Some(forwarded_focus_binding) = element.borrow().bindings.get("forward_focus") {
+    if let Some(forwarded_focus_binding) = element.borrow().bindings.get("forward-focus") {
         if let Expression::ElementReference(target) = &forwarded_focus_binding.expression {
             return FocusCheckResult::FocusForwarded(
                 target.upgrade().unwrap(),
                 forwarded_focus_binding.to_source_location(),
             );
         } else {
-            panic!("internal error: forward_focus property is of type ElementReference but received non-element-reference binding");
+            panic!("internal error: forward-focus property is of type ElementReference but received non-element-reference binding");
         }
     }
 
@@ -39,7 +39,7 @@ fn element_focus_check(element: &ElementRc) -> FocusCheckResult {
         return FocusCheckResult::ElementIsFocusable;
     }
 
-    return FocusCheckResult::ElementIsNotFocusable;
+    FocusCheckResult::ElementIsNotFocusable
 }
 
 fn find_focusable_element(
@@ -55,8 +55,9 @@ fn find_focusable_element(
                 last_focus_forward_location = Some(location);
             }
             FocusCheckResult::ElementIsNotFocusable => {
-                last_focus_forward_location
-                    .map(|location| diag.push_error("element is not focusable".into(), &location));
+                if let Some(location) = last_focus_forward_location {
+                    diag.push_error("element is not focusable".into(), &location);
+                }
                 break None;
             }
         }
@@ -77,7 +78,7 @@ fn resolve_element_reference_in_set_focus_call(expr: &mut Expression, diag: &mut
                 let focus_target = weak_focus_target.upgrade().expect(
                     "internal compiler error: weak SetFocusItem parameter cannot be dangling",
                 );
-                match find_focusable_element(focus_target.clone(), diag) {
+                match find_focusable_element(focus_target, diag) {
                     Some(new_focus_target) => {
                         *weak_focus_target = Rc::downgrade(&new_focus_target);
                     }
@@ -116,10 +117,10 @@ pub fn determine_initial_focus_item(component: &Rc<Component>, diag: &mut BuildD
     }
 }
 
-/// The `forward_focus` property is not a real property that can be generated, so remove any bindings to it
+/// The `forward-focus` property is not a real property that can be generated, so remove any bindings to it
 /// to avoid them being materialized.
 pub fn erase_forward_focus_properties(component: &Rc<Component>) {
     recurse_elem_no_borrow(&component.root_element, &(), &mut |elem, _| {
-        elem.borrow_mut().bindings.remove("forward_focus");
+        elem.borrow_mut().bindings.remove("forward-focus");
     })
 }
