@@ -17,20 +17,36 @@ use crate::expression_tree::*;
 use crate::langtype::Type;
 use crate::layout::*;
 use crate::object_tree::*;
+use crate::typeloader::TypeLoader;
 use crate::typeregister::TypeRegister;
+use std::collections::HashSet;
 use std::rc::Rc;
 
-pub fn lower_layouts(
+pub async fn lower_layouts(
     component: &Rc<Component>,
-    type_register: &TypeRegister,
+    type_loader: &mut TypeLoader<'_>,
     diag: &mut BuildDiagnostics,
 ) {
+    // Ignore import errors
+    let mut build_diags_to_ignore = crate::diagnostics::BuildDiagnostics::default();
+    let style_metrics = type_loader
+        .import_type("sixtyfps_widgets.60", "StyleMetrics", &mut build_diags_to_ignore)
+        .await;
+    let style_metrics =
+        style_metrics.and_then(|sm| if let Type::Component(c) = sm { Some(c) } else { None });
+
     *component.root_constraints.borrow_mut() =
         LayoutConstraints::new(&component.root_element, diag);
 
     recurse_elem_including_sub_components(component, &(), &mut |elem, _| {
         let component = elem.borrow().enclosing_component.upgrade().unwrap();
-        lower_element_layout(&component, elem, type_register, diag);
+        lower_element_layout(
+            &component,
+            elem,
+            &type_loader.global_type_registry.borrow(),
+            &style_metrics,
+            diag,
+        );
         check_no_layout_properties(elem, diag);
     });
 }
@@ -39,6 +55,7 @@ fn lower_element_layout(
     component: &Rc<Component>,
     elem: &ElementRc,
     type_register: &TypeRegister,
+    style_metrics: &Option<Rc<Component>>,
     diag: &mut BuildDiagnostics,
 ) {
     let base_type = if let Type::Builtin(base_type) = &elem.borrow().base_type {
@@ -49,9 +66,13 @@ fn lower_element_layout(
     match base_type.name.as_str() {
         "Row" => panic!("Error caught at element lookup time"),
         "GridLayout" => lower_grid_layout(component, elem, diag),
-        "HorizontalLayout" => lower_box_layout(component, elem, diag, Orientation::Horizontal),
-        "VerticalLayout" => lower_box_layout(component, elem, diag, Orientation::Vertical),
-        "PathLayout" => lower_path_layout(component, elem, diag),
+        "HorizontalLayout" => lower_box_layout(elem, diag, Orientation::Horizontal),
+        "VerticalLayout" => lower_box_layout(elem, diag, Orientation::Vertical),
+        "PathLayout" => lower_path_layout(elem, diag),
+        "Dialog" => {
+            lower_dialog_layout(elem, style_metrics, diag);
+            return; // the Dialog stays in the tree as a Dialog
+        }
         _ => return,
     };
 
@@ -81,6 +102,7 @@ fn lower_grid_layout(
     let mut grid = GridLayout {
         elems: Default::default(),
         geometry: LayoutGeometry::new(grid_layout_element),
+        dialog_button_roles: None,
     };
 
     let layout_cache_prop_h =
@@ -200,6 +222,25 @@ impl GridLayout {
             *col = c;
         }
 
+        self.add_element_with_coord(
+            item_element,
+            (*row, *col),
+            (rowspan, colspan),
+            layout_cache_prop_h,
+            layout_cache_prop_v,
+            diag,
+        )
+    }
+
+    fn add_element_with_coord(
+        &mut self,
+        item_element: &ElementRc,
+        (row, col): (u16, u16),
+        (rowspan, colspan): (u16, u16),
+        layout_cache_prop_h: &NamedReference,
+        layout_cache_prop_v: &NamedReference,
+        diag: &mut BuildDiagnostics,
+    ) {
         let index = self.elems.len();
         if let Some(layout_item) = create_layout_item(item_element, diag) {
             if layout_item.repeater_index.is_some() {
@@ -222,8 +263,8 @@ impl GridLayout {
             }
 
             self.elems.push(GridLayoutElement {
-                col: *col,
-                row: *row,
+                col,
+                row,
                 colspan,
                 rowspan,
                 item: layout_item.item,
@@ -233,7 +274,6 @@ impl GridLayout {
 }
 
 fn lower_box_layout(
-    _component: &Rc<Component>,
     layout_element: &ElementRc,
     diag: &mut BuildDiagnostics,
     orientation: Orientation,
@@ -337,11 +377,199 @@ fn lower_box_layout(
     layout_element.borrow_mut().layout_info_prop = Some((layout_info_prop_h, layout_info_prop_v));
 }
 
-fn lower_path_layout(
-    _component: &Rc<Component>,
-    layout_element: &ElementRc,
+fn lower_dialog_layout(
+    dialog_element: &ElementRc,
+    style_metrics: &Option<Rc<Component>>,
     diag: &mut BuildDiagnostics,
 ) {
+    let mut grid = GridLayout {
+        elems: Default::default(),
+        geometry: LayoutGeometry::new(dialog_element),
+        dialog_button_roles: None,
+    };
+    if let Some(metrics) = style_metrics.as_ref().map(|comp| &comp.root_element) {
+        grid.geometry.padding.bottom.get_or_insert(NamedReference::new(metrics, "layout-padding"));
+        grid.geometry.padding.top.get_or_insert(NamedReference::new(metrics, "layout-padding"));
+        grid.geometry.padding.left.get_or_insert(NamedReference::new(metrics, "layout-padding"));
+        grid.geometry.padding.right.get_or_insert(NamedReference::new(metrics, "layout-padding"));
+        grid.geometry.spacing.get_or_insert(NamedReference::new(metrics, "layout-spacing"));
+    }
+
+    let layout_cache_prop_h = create_new_prop(dialog_element, "layout-cache-h", Type::LayoutCache);
+    let layout_cache_prop_v = create_new_prop(dialog_element, "layout-cache-v", Type::LayoutCache);
+    let layout_info_prop_h = create_new_prop(dialog_element, "layoutinfo-h", layout_info_type());
+    let layout_info_prop_v = create_new_prop(dialog_element, "layoutinfo-v", layout_info_type());
+
+    let mut main_widget = None;
+    let mut button_roles = vec![];
+    let mut seen_buttons = HashSet::new();
+    let layout_children = std::mem::take(&mut dialog_element.borrow_mut().children);
+    for layout_child in &layout_children {
+        let dialog_button_role_binding =
+            layout_child.borrow_mut().bindings.remove("dialog-button-role");
+        let is_button = if let Some(role_binding) = dialog_button_role_binding {
+            if let Expression::EnumerationValue(val) = &role_binding.expression {
+                let en = &val.enumeration;
+                debug_assert_eq!(en.name, "DialogButtonRole");
+                button_roles.push(en.values[val.value].clone());
+                if val.value == 0 {
+                    diag.push_error("The `dialog-button-role` cannot be set explicitly to none".into(), &role_binding);
+                }
+            } else {
+                diag.push_error("The `dialog-button-role` property must be known at compile-time".into(), &role_binding);
+            }
+            true
+        } else if layout_child.borrow().property_declarations.get("kind").map_or(false, |pd| {
+            matches!(&pd.property_type, Type::Enumeration(e) if e.name == "StandardButtonKind")
+        }) {
+            // layout_child is a StandardButton
+            match layout_child.borrow().bindings.get("kind") {
+                None => diag.push_error(
+                    "The `kind` property of the StandardButton in a Dialog must be set".into(),
+                    &*layout_child.borrow(),
+                ),
+                Some(binding) => {
+                    if let Expression::EnumerationValue(val) = &binding.expression {
+                        let en = &val.enumeration;
+                        debug_assert_eq!(en.name, "StandardButtonKind");
+                        let kind = &en.values[val.value];
+                        let role = match kind.as_str() {
+                            "ok" => "accept",
+                            "cancel" => "reject",
+                            "apply" => "apply",
+                            "close" => "reject",
+                            "reset" => "reset",
+                            "help" => "help",
+                            "yes" => "accept",
+                            "no" => "reject",
+                            "abort" => "reject",
+                            "retry" => "accept",
+                            "ignore" => "accept",
+                            _ => unreachable!(),
+                        };
+                        button_roles.push(role.into());
+                        if !seen_buttons.insert(val.value) {
+                            diag.push_error("Duplicated `kind`: There are two StandardButton in this Dialog with the same kind".into(), binding);
+                        } else if Rc::ptr_eq(
+                            dialog_element,
+                            &dialog_element
+                                .borrow()
+                                .enclosing_component
+                                .upgrade()
+                                .unwrap()
+                                .root_element,
+                        ) {
+                            let clicked_ty =
+                                layout_child.borrow().lookup_property("clicked").property_type;
+                            if matches!(&clicked_ty, Type::Callback { .. })
+                                && layout_child
+                                    .borrow()
+                                    .bindings
+                                    .get("clicked")
+                                    .map_or(true, |c| matches!(c.expression, Expression::Invalid))
+                            {
+                                dialog_element
+                                    .borrow_mut()
+                                    .property_declarations
+                                    .entry(format!("{}-clicked", kind))
+                                    .or_insert_with(|| PropertyDeclaration {
+                                        property_type: clicked_ty,
+                                        node: None,
+                                        expose_in_public_api: true,
+                                        is_alias: Some(NamedReference::new(
+                                            layout_child,
+                                            "clicked",
+                                        )),
+                                    });
+                            }
+                        }
+                    } else {
+                        diag.push_error(
+                            "The `kind` property of the StandardButton in a Dialog must be known at compile-time"
+                                .into(),
+                            binding,
+                        );
+                    }
+                }
+            }
+            true
+        } else {
+            false
+        };
+
+        if is_button {
+            grid.add_element_with_coord(
+                layout_child,
+                (1, button_roles.len() as u16),
+                (1, 1),
+                &layout_cache_prop_h,
+                &layout_cache_prop_v,
+                diag,
+            );
+        } else if main_widget.is_some() {
+            diag.push_error(
+                "A Dialog can have only one child element that is not a StandardButton".into(),
+                &*layout_child.borrow(),
+            );
+        } else {
+            main_widget = Some(layout_child.clone())
+        }
+    }
+    dialog_element.borrow_mut().children = layout_children;
+
+    if let Some(main_widget) = main_widget {
+        grid.add_element_with_coord(
+            &main_widget,
+            (0, 0),
+            (1, button_roles.len() as u16 + 1),
+            &layout_cache_prop_h,
+            &layout_cache_prop_v,
+            diag,
+        );
+    } else {
+        diag.push_error(
+            "A Dialog must have a single child element that is not StandardButton".into(),
+            &*dialog_element.borrow(),
+        );
+    }
+    grid.dialog_button_roles = Some(button_roles);
+
+    let span = dialog_element.borrow().to_source_location();
+    layout_cache_prop_h.element().borrow_mut().bindings.insert(
+        layout_cache_prop_h.name().into(),
+        BindingExpression::new_with_span(
+            Expression::SolveLayout(Layout::GridLayout(grid.clone()), Orientation::Horizontal),
+            span.clone(),
+        ),
+    );
+    layout_cache_prop_v.element().borrow_mut().bindings.insert(
+        layout_cache_prop_v.name().into(),
+        BindingExpression::new_with_span(
+            Expression::SolveLayout(Layout::GridLayout(grid.clone()), Orientation::Vertical),
+            span.clone(),
+        ),
+    );
+    layout_info_prop_h.element().borrow_mut().bindings.insert(
+        layout_info_prop_h.name().into(),
+        BindingExpression::new_with_span(
+            Expression::ComputeLayoutInfo(
+                Layout::GridLayout(grid.clone()),
+                Orientation::Horizontal,
+            ),
+            span.clone(),
+        ),
+    );
+    layout_info_prop_v.element().borrow_mut().bindings.insert(
+        layout_info_prop_v.name().into(),
+        BindingExpression::new_with_span(
+            Expression::ComputeLayoutInfo(Layout::GridLayout(grid), Orientation::Vertical),
+            span,
+        ),
+    );
+    dialog_element.borrow_mut().layout_info_prop = Some((layout_info_prop_h, layout_info_prop_v));
+}
+
+fn lower_path_layout(layout_element: &ElementRc, diag: &mut BuildDiagnostics) {
     let layout_cache_prop = create_new_prop(layout_element, "layout-cache", Type::LayoutCache);
 
     let path_elements_expr = match layout_element.borrow_mut().bindings.remove("elements") {
@@ -546,5 +774,8 @@ fn check_no_layout_properties(item: &ElementRc, diag: &mut BuildDiagnostics) {
         if matches!(prop.as_ref(), "col" | "row" | "colspan" | "rowspan") {
             diag.push_error(format!("{} used outside of a GridLayout", prop), expr);
         }
+        if matches!(prop.as_ref(), "dialog-button-role") {
+            diag.push_error(format!("{} used outside of a Dialog", prop), expr);
+        }
     }
 }
