@@ -28,13 +28,6 @@ pub struct LoadedDocuments {
     currently_loading: HashSet<PathBuf>,
 }
 
-pub struct VirtualFile<'a> {
-    pub path: &'a str,
-    pub contents: &'a str,
-}
-
-pub type VirtualDirectory<'a> = [&'a VirtualFile<'a>];
-
 pub struct ImportedTypes {
     pub import_token: SyntaxToken,
     pub imported_types: syntax_nodes::ImportSpecifier,
@@ -153,7 +146,7 @@ impl<'a> TypeLoader<'a> {
         let doc = self.all_documents.docs.get(&doc_path).unwrap();
 
         doc.exports().iter().find_map(|(export_name, ty)| {
-            if type_name == *export_name {
+            if type_name == export_name.as_str() {
                 Some(ty.clone())
             } else {
                 None
@@ -167,7 +160,7 @@ impl<'a> TypeLoader<'a> {
         &self,
         import_token: Option<&NodeOrToken>,
         maybe_relative_path_or_url: &str,
-    ) -> (std::path::PathBuf, Option<&'_ str>) {
+    ) -> (std::path::PathBuf, Option<&'static [u8]>) {
         let referencing_file_or_url =
             import_token.and_then(|tok| tok.source_file().map(|s| s.path()));
 
@@ -222,7 +215,8 @@ impl<'a> TypeLoader<'a> {
         }
 
         let source_code_result = if let Some(builtin) = builtin {
-            Ok(builtin)
+            Ok(String::from_utf8(builtin)
+                .expect("internal error: embedded file is not UTF-8 source code"))
         } else if let Some(fallback) = &self.compiler_config.open_import_fallback {
             let result = fallback(path_canon.to_string_lossy().into()).await;
             result.unwrap_or_else(|| std::fs::read_to_string(&path_canon))
@@ -332,7 +326,7 @@ impl<'a> TypeLoader<'a> {
 
             for import_name in imported_types {
                 let imported_type = exports.iter().find_map(|(export_name, ty)| {
-                    if import_name.external_name == *export_name {
+                    if import_name.external_name == export_name.as_str() {
                         Some(ty.clone())
                     } else {
                         None
@@ -366,7 +360,7 @@ impl<'a> TypeLoader<'a> {
         &self,
         referencing_file: Option<&std::path::Path>,
         file_to_import: &str,
-    ) -> Option<(PathBuf, Option<&str>)> {
+    ) -> Option<(PathBuf, Option<&'static [u8]>)> {
         // The directory of the current file is the first in the list of include directories.
         let maybe_current_directory =
             referencing_file.and_then(|path| path.parent()).map(|p| p.to_path_buf());
@@ -385,29 +379,8 @@ impl<'a> TypeLoader<'a> {
             .chain(std::iter::once_with(|| format!("builtin:/{}", self.style).into()))
             .find_map(|include_dir| {
                 let candidate = include_dir.join(file_to_import);
-                match candidate.strip_prefix("builtin:/") {
-                    Err(_) => candidate.exists().then(|| (candidate, None)),
-                    Ok(builtin) => {
-                        let mut components = vec![];
-                        for part in builtin.iter() {
-                            if part == ".." {
-                                components.pop();
-                            } else if part != "." {
-                                components.push(part);
-                            }
-                        }
-                        if let &[folder, file] = components.as_slice() {
-                            let library =
-                                crate::library::widget_library().iter().find(|x| x.0 == folder)?.1;
-                            library
-                                .iter()
-                                .find(|vf| vf.path == file)
-                                .map(|vf| (candidate, Some(vf.contents)))
-                        } else {
-                            None
-                        }
-                    }
-                }
+                crate::fileaccess::load_file(&candidate)
+                    .map(|virtual_file| (candidate, virtual_file.builtin_contents))
             })
     }
 
